@@ -84,6 +84,8 @@ const struct arch_def arch_def_mips64 = {
 	.syscall_resolve_num_raw = mips64_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = mips64_syscall_name_kver,
+	.syscall_num_kver = mips64_syscall_num_kver,
 };
 
 const struct arch_def arch_def_mipsel64 = {
@@ -97,4 +99,6 @@ const struct arch_def arch_def_mipsel64 = {
 	.syscall_resolve_num_raw = mips64_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = mips64_syscall_name_kver,
+	.syscall_num_kver = mips64_syscall_num_kver,
 };
