@@ -26,12 +26,14 @@
 
 #include "arch.h"
 #include "arch-mips64n32.h"
+#include "syscalls.h"
 
 /* N32 ABI */
 #define __SCMP_NR_BASE			6000
 
 /**
  * Resolve a syscall name to a number
+ * @param arch the architecture definition
  * @param name the syscall name
  *
  * Resolve the given syscall name to the syscall number using the syscall table.
@@ -39,7 +41,8 @@
  * numbers; returns __NR_SCMP_ERROR on failure.
  *
  */
-int mips64n32_syscall_resolve_name_munge(const char *name)
+int mips64n32_syscall_resolve_name_munge(const struct arch_def *arch,
+					 const char *name)
 {
 	int sys;
 
@@ -53,6 +56,7 @@ int mips64n32_syscall_resolve_name_munge(const char *name)
 
 /**
  * Resolve a syscall number to a name
+ * @param arch the architecture definition
  * @param num the syscall number
  *
  * Resolve the given syscall number to the syscall name using the syscall table.
@@ -60,7 +64,8 @@ int mips64n32_syscall_resolve_name_munge(const char *name)
  * syscall names; returns NULL on failure.
  *
  */
-const char *mips64n32_syscall_resolve_num_munge(int num)
+const char *mips64n32_syscall_resolve_num_munge(const struct arch_def *arch,
+						int num)
 {
 	/* NOTE: we don't want to modify the pseudo-syscall numbers */
 	if (num >= __SCMP_NR_BASE)
@@ -68,15 +73,21 @@ const char *mips64n32_syscall_resolve_num_munge(int num)
 	return mips64n32_syscall_resolve_num(num);
 }
 
+ARCH_DEF(mips64n32)
+
 const struct arch_def arch_def_mips64n32 = {
 	.token = SCMP_ARCH_MIPS64N32,
 	.token_bpf = AUDIT_ARCH_MIPS64N32,
 	.size = ARCH_SIZE_32,
 	.endian = ARCH_ENDIAN_BIG,
 	.syscall_resolve_name = mips64n32_syscall_resolve_name_munge,
+	.syscall_resolve_name_raw = mips64n32_syscall_resolve_name,
 	.syscall_resolve_num = mips64n32_syscall_resolve_num_munge,
+	.syscall_resolve_num_raw = mips64n32_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = mips64n32_syscall_name_kver,
+	.syscall_num_kver = mips64n32_syscall_num_kver,
 };
 
 const struct arch_def arch_def_mipsel64n32 = {
@@ -85,7 +96,11 @@ const struct arch_def arch_def_mipsel64n32 = {
 	.size = ARCH_SIZE_32,
 	.endian = ARCH_ENDIAN_LITTLE,
 	.syscall_resolve_name = mips64n32_syscall_resolve_name_munge,
+	.syscall_resolve_name_raw = mips64n32_syscall_resolve_name,
 	.syscall_resolve_num = mips64n32_syscall_resolve_num_munge,
+	.syscall_resolve_num_raw = mips64n32_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = mips64n32_syscall_name_kver,
+	.syscall_num_kver = mips64n32_syscall_num_kver,
 };
