@@ -31,4 +31,6 @@ const struct arch_def arch_def_riscv64 = {
 	.syscall_resolve_num_raw = riscv64_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = riscv64_syscall_name_kver,
+	.syscall_num_kver = riscv64_syscall_num_kver,
 };
