@@ -38,4 +38,6 @@ const struct arch_def arch_def_x86_64 = {
 	.syscall_resolve_num_raw = x86_64_syscall_resolve_num,
 	.syscall_rewrite = NULL,
 	.rule_add = NULL,
+	.syscall_name_kver = x86_64_syscall_name_kver,
+	.syscall_num_kver = x86_64_syscall_num_kver,
 };
