@@ -4,7 +4,7 @@
 # Seccomp Library test program
 #
 # Copyright (c) 2012 Red Hat <pmoore@redhat.com>
-# Author: Paul Moore <pmoore@redhat.com>
+# Author: Paul Moore <paul@paul-moore.com>
 #
 
 #
@@ -81,6 +81,17 @@ def test():
     except RuntimeError:
         pass
 
+    f = SyscallFilter(ALLOW)
+    try:
+        f.add_rule(ERRNO(0xffff), "read")
+    except RuntimeError:
+        pass
+
+    # This shouldn't throw any errors.
+    f = SyscallFilter(ALLOW)
+    f.add_rule(KILL, "read")
+    ret = f.export_bpf_mem()
+
 test()
 
 # kate: syntax python;
