@@ -43,6 +43,9 @@ int main(int argc, char *argv[])
 	if (rc != 0)
 		goto out;
 
+	rc = seccomp_arch_add(ctx, seccomp_arch_resolve_name("m68k"));
+	if (rc != 0)
+		goto out;
 	rc = seccomp_arch_add(ctx, seccomp_arch_resolve_name("mips"));
 	if (rc != 0)
 		goto out;
@@ -68,6 +71,9 @@ int main(int argc, char *argv[])
 	if (rc != 0)
 		goto out;
 	rc = seccomp_arch_add(ctx, seccomp_arch_resolve_name("s390x"));
+	if (rc != 0)
+		goto out;
+	rc = seccomp_arch_add(ctx, seccomp_arch_resolve_name("sheb"));
 	if (rc != 0)
 		goto out;
 
