@@ -44,6 +44,10 @@
 #define ARCH_NATIVE		AUDIT_ARCH_ARM
 #elif __aarch64__
 #define ARCH_NATIVE		AUDIT_ARCH_AARCH64
+#elif __loongarch_lp64
+#define ARCH_NATIVE		AUDIT_ARCH_LOONGARCH64
+#elif __m68k__
+#define ARCH_NATIVE		AUDIT_ARCH_M68K
 #elif __mips__ && _MIPS_SIM == _MIPS_SIM_ABI32
 #if __MIPSEB__
 #define ARCH_NATIVE		AUDIT_ARCH_MIPS
@@ -78,6 +82,14 @@
 #define ARCH_NATIVE		AUDIT_ARCH_S390X
 #elif __s390__
 #define ARCH_NATIVE		AUDIT_ARCH_S390
+#elif __riscv && __riscv_xlen == 64
+#define ARCH_NATIVE		AUDIT_ARCH_RISCV64
+#elif __sh__
+#ifdef __BIG_ENDIAN__
+#define ARCH_NATIVE		AUDIT_ARCH_SH
+#else
+#define ARCH_NATIVE		AUDIT_ARCH_SHEL
+#endif
 #else
 #error the simulator code needs to know about your machine type
 #endif
@@ -86,64 +98,64 @@
 uint32_t arch = ARCH_NATIVE;
 
 /**
- * Convert a 16-bit target integer into the host's endianess
- * @param arch the architecture token
+ * Convert a 16-bit target integer into the host's endianness
+ * @param arch_token the architecture token
  * @param val the 16-bit integer
  *
- * Convert the endianess of the supplied value and return it to the caller.
+ * Convert the endianness of the supplied value and return it to the caller.
  *
  */
-uint16_t ttoh16(uint32_t arch, uint16_t val)
+uint16_t ttoh16(uint32_t arch_token, uint16_t val)
 {
-	if (arch & __AUDIT_ARCH_LE)
+	if (arch_token & __AUDIT_ARCH_LE)
 		return le16toh(val);
 	else
 		return be16toh(val);
 }
 
 /**
- * Convert a 32-bit target integer into the host's endianess
- * @param arch the architecture token
+ * Convert a 32-bit target integer into the host's endianness
+ * @param arch_token the architecture token
  * @param val the 32-bit integer
  *
- * Convert the endianess of the supplied value and return it to the caller.
+ * Convert the endianness of the supplied value and return it to the caller.
  *
  */
-uint32_t ttoh32(uint32_t arch, uint32_t val)
+uint32_t ttoh32(uint32_t arch_token, uint32_t val)
 {
-	if (arch & __AUDIT_ARCH_LE)
+	if (arch_token & __AUDIT_ARCH_LE)
 		return le32toh(val);
 	else
 		return be32toh(val);
 }
 
 /**
- * Convert a 32-bit host integer into the target's endianess
- * @param arch the architecture token
+ * Convert a 32-bit host integer into the target's endianness
+ * @param arch_token the architecture token
  * @param val the 32-bit integer
  *
- * Convert the endianess of the supplied value and return it to the caller.
+ * Convert the endianness of the supplied value and return it to the caller.
  *
  */
-uint32_t htot32(uint32_t arch, uint32_t val)
+uint32_t htot32(uint32_t arch_token, uint32_t val)
 {
-	if (arch & __AUDIT_ARCH_LE)
+	if (arch_token & __AUDIT_ARCH_LE)
 		return htole32(val);
 	else
 		return htobe32(val);
 }
 
 /**
- * Convert a 64-bit host integer into the target's endianess
- * @param arch the architecture token
+ * Convert a 64-bit host integer into the target's endianness
+ * @param arch_token the architecture token
  * @param val the 64-bit integer
  *
- * Convert the endianess of the supplied value and return it to the caller.
+ * Convert the endianness of the supplied value and return it to the caller.
  *
  */
-uint64_t htot64(uint32_t arch, uint64_t val)
+uint64_t htot64(uint32_t arch_token, uint64_t val)
 {
-	if (arch & __AUDIT_ARCH_LE)
+	if (arch_token & __AUDIT_ARCH_LE)
 		return htole64(val);
 	else
 		return htobe64(val);
